@@ -1,4 +1,4 @@
-# Copyright 2022 Mathias Lechner
+# Copyright 2022 Mathias Lechner and Ramin Hasani
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -45,18 +45,23 @@ class CfCCell(nn.Module):
         backbone_dropout=0.0,
         sparsity_mask=None,
     ):
+        """A `Closed-form Continuous-time <https://arxiv.org/abs/2106.13898>`_ cell.
+
+        .. Note::
+            This is an RNNCell that process single time-steps. To get a full RNN that can process sequences see `ncps.torch.CfC`.
+
+
+
+        :param input_size:
+        :param hidden_size:
+        :param mode:
+        :param backbone_activation:
+        :param backbone_units:
+        :param backbone_layers:
+        :param backbone_dropout:
+        :param sparsity_mask:
         """
 
-        Args:
-            input_size:
-            hidden_size:
-            mode:
-            backbone_activation:
-            backbone_units:
-            backbone_layers:
-            backbone_dropout:
-            sparsity_mask:
-        """
         super(CfCCell, self).__init__()
 
         self.input_size = input_size
@@ -89,17 +94,20 @@ class CfCCell(nn.Module):
             backbone_activation = LeCun
         else:
             raise ValueError(f"Unknown activation {backbone_activation}")
-        layer_list = [
-            nn.Linear(input_size + hidden_size, backbone_units),
-            backbone_activation(),
-        ]
-        for i in range(1, backbone_layers):
-            layer_list.append(nn.Linear(backbone_units, backbone_units))
-            layer_list.append(backbone_activation())
-            if backbone_dropout > 0.0:
-                layer_list.append(torch.nn.Dropout(backbone_dropout))
-        self.backbone = nn.Sequential(*layer_list)
+
+        self.backbone = None
         self.backbone_layers = backbone_layers
+        if backbone_layers > 0:
+            layer_list = [
+                nn.Linear(input_size + hidden_size, backbone_units),
+                backbone_activation(),
+            ]
+            for i in range(1, backbone_layers):
+                layer_list.append(nn.Linear(backbone_units, backbone_units))
+                layer_list.append(backbone_activation())
+                if backbone_dropout > 0.0:
+                    layer_list.append(torch.nn.Dropout(backbone_dropout))
+            self.backbone = nn.Sequential(*layer_list)
         self.tanh = nn.Tanh()
         self.sigmoid = nn.Sigmoid()
         cat_shape = int(
